@@ -89,6 +89,9 @@ def up(
 
     cmd = f"python service.py {settings.REDIS_HOST} {model_config} {sim_uid} {sim_ref_datetime} {end_time} {duration} {start_mode} {pause_timeout} {max_rate} {clean_up_files}" # noqa
 
+
+    skip_model_mount: bool = all([x for x in [gridadmin_download_url, tables_download_url]])
+
     if gridadmin_download_url is not None:
         cmd += f" {gridadmin_download_url}"
     if tables_download_url is not None:
@@ -99,6 +102,9 @@ def up(
 
     mounts = []
     for local_path, mount_setting in settings.DOCKER_MOUNT_POINTS.items():
+        if skip_model_mount and mount_setting['bind'] == '/models':
+            # Skip mounting models
+            continue
         mounts.append(
             Mount(
                 mount_setting["bind"],
