@@ -90,7 +90,13 @@ def up(
 
     volumes = []  # == mounts
 
+    skip_model_mount: bool = all([x for x in [gridadmin_download_url, tables_download_url]])
+
     for local_path, mount_setting in settings.DOCKER_MOUNT_POINTS.items():
+        if skip_model_mount and mount_setting['bind'] == '/models':
+            # Skip mounting models
+            continue
+
         volumes.append(
             MarathonContainerVolume(
                 container_path=mount_setting["bind"],
